@@ -27,7 +27,7 @@ def cert2asn(cert, cert_bytes=True):
         _, _, cert_bytes = pem.unarmor(cert_bytes)
     return x509.Certificate.load(cert_bytes)
 
-def sign(datau, key, cert, othercerts, hashalgo, attrs=True, signed_value=None, hsm=None, pss=False, timestampurl=None, timestampcredentials=None):
+def sign(datau, key, cert, othercerts, hashalgo, attrs=True, signed_value=None, hsm=None, pss=False, timestampurl=None, timestampcredentials=None, timestamp_req_options=None):
     if signed_value is None:
         signed_value = getattr(hashlib, hashalgo)(datau).digest()
     signed_time = datetime.now(tz=util.timezone.utc)
@@ -180,7 +180,9 @@ def sign(datau, key, cert, othercerts, hashalgo, attrs=True, signed_value=None,
             if username and password:
                 auth_header_value = b64encode(bytes(username + ':' + password, "utf-8")).decode("ascii")
                 tspheaders["Authorization"] = f"Basic {auth_header_value}"
-        tspresp = requests.post(timestampurl, data=tspreq, headers=tspheaders)
+        if timestamp_req_options is None:
+            timestamp_req_options = {}
+        tspresp = requests.post(timestampurl, data=tspreq, headers=tspheaders, **timestamp_req_options)
         if tspresp.headers.get('Content-Type', None) == 'application/timestamp-reply':
             tspresp = tsp.TimeStampResp.load(tspresp.content)
 
